package com.diagbot.facade;

import com.diagbot.dto.ProductAuthProgressDTO;
import com.diagbot.entity.LantoneProduct;
import com.diagbot.entity.OrderDetails;
import com.diagbot.entity.ProductOrder;
import com.diagbot.entity.ServiceInfo;
import com.diagbot.enums.VisibleIdTypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.idc.VisibleIdCreater;
import com.diagbot.service.impl.ProductOrderServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.UserUtils;
import com.diagbot.vo.AddOrderVO;
import com.diagbot.vo.ProductServiceSaveVO;
import com.diagbot.vo.ServiceSaveVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * 订单业务
 * @author Administrator
 *
 */
@Component
public class ProductOrderFacade extends ProductOrderServiceImpl {
	@Autowired
	private VisibleIdCreater visibleIdCreater;
	@Autowired
	private OrderDetailsFacade orderDetailsFacade;
	@Autowired
	private ServiceInfoFacade serviceInfoFacade;
	@Autowired
	private LantoneProductFacade lantoneProductFacade;
	@Autowired
	private ProductServiceFacade productServiceFacade;

	public List<ProductAuthProgressDTO> productAuthProgress(){
		List<ProductAuthProgressDTO> retList = new ArrayList<ProductAuthProgressDTO>();
		Long userId = Long.parseLong(UserUtils.getCurrentPrincipleID());
		List<ProductOrder> orderList = baseMapper.getUserProductOrder(userId);
		for(ProductOrder i : orderList){
			ProductAuthProgressDTO productAuthProgressDTO = new ProductAuthProgressDTO();
			productAuthProgressDTO.setNum(i.getNum());
			productAuthProgressDTO.setProducts(baseMapper.getOrderDetails(i.getNum()));
			retList.add(productAuthProgressDTO);
		}

		return retList;
	}

	/**
	 * @Description: 根据用户选择的产品生成订单
	 * @Author: wangyu
	 * @Date: 19:59 2018/9/18
	 */
	@Transactional
	public CommonErrorCode addOrders(AddOrderVO addOrderVO){
		Long userId = Long.parseLong(UserUtils.getCurrentPrincipleID());
		ProductOrder productOrder =new ProductOrder();
		productOrder.setCreator(UserUtils.getCurrentPrincipleID());
		productOrder.setGmtCreate(DateUtil.now());
		String imgId = visibleIdCreater.getNextId(VisibleIdTypeEnum.IS_ORDER.getKey()).toString();
		productOrder.setNum(imgId);
		productOrder.setUserId(userId);
		productOrder.setTime(DateUtil.now());
		if(!save(productOrder)){
			return CommonErrorCode.FAIL;
		}
		for (Long o:addOrderVO.getProductId()
				) {
			LantoneProduct lantoneProduct = lantoneProductFacade.selectLanProduct(o);
			if(null==lantoneProduct){
				return CommonErrorCode.FAIL;
			}
			OrderDetails orderDetails =new OrderDetails();
			orderDetails.setUserId(1l);
			orderDetails.setOrderNum(imgId);
			orderDetails.setGmtCreate(DateUtil.now());
			orderDetails.setCreator("");
			orderDetails.setProductId(o);
			if(orderDetailsFacade.addOrderDetails(orderDetails)){
				ServiceSaveVO serviceSaveVO =new ServiceSaveVO();
				ProductServiceSaveVO productServiceSaveVO =new ProductServiceSaveVO();
				serviceSaveVO.setDescription(lantoneProduct.getDecription());
				serviceSaveVO.setName(lantoneProduct.getName());
				serviceSaveVO.setType(1);
				ServiceInfo serviceInfo = serviceInfoFacade.createService(serviceSaveVO);
				productServiceSaveVO.setProductId(o);
				productServiceSaveVO.setServiceId(serviceInfo.getId());
				productServiceSaveVO.setType(1);
				productServiceFacade.genProductService(productServiceSaveVO);
			}
		}

		return CommonErrorCode.OK;
	}

	/**
	 * @Description:  根据订单号查询订单信息
	 * @Author: wangyu
	 * @Date: 19:42 2018/9/20
	 */
	public ProductOrder selectByOrderNum(ProductOrder productOrder){
		return selctOrderTimeByOrderNum(productOrder);
	}
}
