package com.diagbot.web;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.EnShowOptionDTO;
import com.diagbot.dto.GetConsoleOnTrialDTO;
import com.diagbot.dto.GetConsoleOpenedDTO;
import com.diagbot.dto.OpenUpOnTrialDTO;
import com.diagbot.dto.ProductAuthProgressDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.UserAndProdutDTO;
import com.diagbot.entity.OpenedProducts;
import com.diagbot.facade.OpenedProductsFacade;
import com.diagbot.facade.ProductOrderFacade;
import com.diagbot.util.DateUtil;
import com.diagbot.vo.ModifyOpeningTimeVO;
import com.diagbot.vo.OpenUpOnTrialVO;
import com.diagbot.vo.StartAndendByUserIdVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @author rgb
 *
 */
@Api(value="控制台-产品操作API", tags={"控制台-产品操作API"})
@RestController
@RequestMapping("/productOrder")
public class ProductOrderController {

	@Autowired
	private ProductOrderFacade productOrderFacade;
	@Autowired
	private OpenedProductsFacade openedProductsFacade;

	@ApiOperation(value = "控制台-产品认证进度",notes="控制台-产品认证进度")
	@PostMapping("/productAuthProgress")
	@SysLogger("productAuthProgress")
	public RespDTO<List<ProductAuthProgressDTO>> productAuthProgress() {
		return RespDTO.onSuc(productOrderFacade.productAuthProgress());
	}
	
	@ApiOperation(value = "控制台-已开通产品",notes="控制台-已开通产品")
	@PostMapping("/getConsoleOpened")
	@SysLogger("getConsoleOpened")
	public RespDTO<List<GetConsoleOpenedDTO>> getConsoleOpened() {
		return RespDTO.onSuc(openedProductsFacade.getConsoleOpened());
	}
	
	@ApiOperation(value = "控制台-可试用产品",notes="控制台-可试用产品")
	@PostMapping("/getConsoleOnTrial")
	@SysLogger("getConsoleOnTrial")
	public RespDTO<List<GetConsoleOnTrialDTO>> getConsoleOnTrial() {
		return RespDTO.onSuc(openedProductsFacade.getConsoleOnTrial());
	}
	
	@ApiOperation(value = "控制台-产品立即试用接口",notes="控制台-产品立即试用接口")
	@PostMapping("/openUpOnTrial")
	@SysLogger("openUpOnTrial")
	public RespDTO<OpenUpOnTrialDTO> openUpOnTrial(OpenUpOnTrialVO openUpOnTrialVO) {
		return RespDTO.onSuc(openedProductsFacade.openUpOnTrial(openUpOnTrialVO));
	}
	
	@ApiOperation(value = "控制台-可展示的选项卡",notes="控制台-可展示的选项卡")
	@PostMapping("/enShowOption")
	@SysLogger("enShowOption")
	public RespDTO<EnShowOptionDTO> enShowOption() {
		return RespDTO.onSuc(openedProductsFacade.enShowOption());
	}
	
	   
    @ApiOperation(value = "根据用户id查询已开通的功能", notes = "已开通信息")
    @PostMapping("/getInformationAvailableByUserId")
    @SysLogger("getInformationAvailableByUserId")
    public RespDTO  getInformationAvailableByUserId(Long userId){
    	List<UserAndProdutDTO> UserAndProdutData = openedProductsFacade.getInformationAvailableByUserId(userId);
    	return RespDTO.onSuc(UserAndProdutData);
    }

	@ApiOperation(value = "根据用户id和产品id，启用和停用功能", notes = "开通信息")
	@PostMapping("/startAndendByuserId")
	@SysLogger("startAndendByuserId")
	public RespDTO<StartAndendByUserIdVO> startAndendByuserId(StartAndendByUserIdVO startAndendByUserIdVO) {
		OpenedProducts openedProducts = new OpenedProducts();
		openedProducts.setUserId(startAndendByUserIdVO.getUserId());
		openedProducts.setProductId(startAndendByUserIdVO.getProductId());
		openedProducts.setCreator("");
		openedProducts.setGmtCreate(DateUtil.now());
		openedProducts.setServiceStatus(startAndendByUserIdVO.getServiceStatus());
		openedProductsFacade.startAndendByuserId(openedProducts);
		return RespDTO.onSuc("");
	}

	// TODO
	@ApiOperation(value = "根据用户id和产品id，删除开通信息", notes = "删除开通信息")
	@PostMapping("/delInformationAvailable")
	@SysLogger("delInformationAvailable")
	public RespDTO delInformationAvailable(Long userId, Long productId) {
		OpenedProducts openedProducts = new OpenedProducts();
		openedProducts.setUserId(userId);
		openedProducts.setProductId(productId);
		openedProducts.setCreator("");
		openedProducts.setGmtCreate(DateUtil.now());
		openedProductsFacade.delInformationAvailable(openedProducts);
		return RespDTO.onSuc("");
	}

	// TODO
	@ApiOperation(value = "根据用户id和产品id，修改开通时间", notes = "修改开通时间")
	@PostMapping("/modifyOpeningTime")
	@SysLogger("modifyOpeningTime")
	public RespDTO<ModifyOpeningTimeVO> modifyOpeningTime(ModifyOpeningTimeVO modifyOpeningTimeVO) {
		OpenedProducts openedProducts = new OpenedProducts();
		openedProducts.setUserId(modifyOpeningTimeVO.getUserId());
		openedProducts.setProductId(modifyOpeningTimeVO.getProductId());
		openedProducts.setStartTime(modifyOpeningTimeVO.getStartTime());
		openedProducts.setEndTime(modifyOpeningTimeVO.getEndTime());
		openedProducts.setCreator("");
		openedProducts.setGmtCreate(DateUtil.now());
		openedProductsFacade.modifyOpeningTime(openedProducts);
		return RespDTO.onSuc("");
	}


}
